@@ -57,32 +57,8 @@ pub fn sync_one_crate_entry(
         )
     };
 
-    let crate_name = format!("{}-{}.crate", &crate_entry.name, &crate_entry.vers);
-
-    let crate_path = match crate_entry.name.len() {
-        1 => PathBuf::from("1"),
-        2 => PathBuf::from("2"),
-        3 => PathBuf::from("3"),
-        n if n >= 4 => {
-            let first_two = &crate_entry
-                .name
-                .get(0..2)
-                .expect("crate name len >= 4 but couldn't get first 2 chars");
-            let second_two = &crate_entry
-                .name
-                .get(2..4)
-                .expect("crate name len >= 4 but couldn't get second 2 chars");
-            [first_two, second_two].iter().collect()
-        }
-        _ => return Err(DownloadError::BadCrate("Empty crate name".into())),
-    };
-
-    let file_path = path
-        .join("crates")
-        .join(crate_path)
-        .join(&crate_entry.name)
-        .join(&crate_entry.vers)
-        .join(crate_name);
+    let file_path = get_crate_path(path, &crate_entry.name, &crate_entry.vers)
+        .ok_or_else(|| DownloadError::BadCrate(crate_entry.name.clone()))?;
 
     download(
         &url[..],
@@ -306,3 +282,30 @@ pub fn is_new_crates_format(path: &Path) -> Result<bool, io::Error> {
 
     Ok(true)
 }
+
+pub fn get_crate_path(
+    mirror_path: &Path,
+    crate_name: &str,
+    crate_version: &str,
+) -> Option<PathBuf> {
+    let crate_path = match crate_name.len() {
+        1 => PathBuf::from("1"),
+        2 => PathBuf::from("2"),
+        3 => PathBuf::from("3"),
+        n if n >= 4 => {
+            let first_two = crate_name.get(0..2)?;
+            let second_two = crate_name.get(2..4)?;
+            [first_two, second_two].iter().collect()
+        }
+        _ => return None,
+    };
+
+    Some(
+        mirror_path
+            .join("crates")
+            .join(crate_path)
+            .join(crate_name)
+            .join(crate_version)
+            .join(format!("{}-{}.crate", crate_name, crate_version)),
+    )
+}
