@@ -1,7 +1,6 @@
 use serde::Serialize;
 use std::{io, num::TryFromIntError, path::Path};
 
-use console::style;
 use git2::{
     build::{CheckoutBuilder, RepoBuilder},
     FetchOptions, RemoteCallbacks, Repository, Signature,
@@ -9,7 +8,7 @@ use git2::{
 use thiserror::Error;
 
 use crate::mirror::ConfigCrates;
-use crate::progress_bar::{progress_bar, ProgressBarMessage};
+use crate::progress_bar::{padded_prefix_message, progress_bar, ProgressBarMessage};
 
 #[derive(Error, Debug)]
 pub enum IndexSyncError {
@@ -38,7 +37,7 @@ pub fn sync_crates_repo(mirror_path: &Path, crates: &ConfigCrates) -> Result<(),
     let repo_path = mirror_path.join("crates.io-index");
 
     // Set up progress bar piping.
-    let prefix = format!("{} Fetching crates.io-index... ", style("[1/3]").bold());
+    let prefix = padded_prefix_message(1, 3, "Fetching crates.io-index");
     let (pb_thread, sender) = progress_bar(None, prefix);
 
     // Libgit2 has callbacks that allow us to update the progress bar
@@ -60,9 +59,14 @@ pub fn sync_crates_repo(mirror_path: &Path, crates: &ConfigCrates) -> Result<(),
         clone_repository(fetch_opts, &crates.source_index, &repo_path)?
     } else {
         // Get (fetch) the branch's latest remote "master" commit
-        let repo = Repository::open(repo_path)?;
+        let repo = Repository::open(&repo_path)?;
         let mut remote = repo.find_remote("origin")?;
         remote.fetch(&["master"], Some(&mut fetch_opts), None)?;
+
+        // Set master to origin/master.
+        //
+        // Note that this means config.json changes will have to be rewritten on every sync.
+        fast_forward(&repo_path)?;
     }
 
     sender
@@ -89,8 +93,6 @@ pub fn update_crates_config(
 
 /// Perform a git fast-forward on the repository. This will destroy any local changes that have
 /// been made to the repo, and will make the local master identical to the remote master.
-///
-/// Note that this means config.json changes will have to be rewritten on every sync.
 fn fast_forward(repo_path: &Path) -> Result<(), IndexSyncError> {
     let repo = Repository::open(repo_path)?;
 
@@ -138,16 +140,15 @@ pub fn rewrite_config_json(repo_path: &Path, base_url: &str) -> Result<(), Index
     let refname = "refs/heads/master";
     let signature = Signature::now("Panamax", "panamax@panamax")?;
 
-    eprintln!("{} Syncing index and config... ", style("[3/3]").bold());
-
-    // Set master to origin/master.
-    fast_forward(&repo_path)?;
+    eprintln!("{}", padded_prefix_message(3, 3, "Syncing config"));
 
     let mut index = repo.index()?;
 
+    let crate_path = format!("{}/{}", base_url, "{crate}/{crate}-{version}.crate");
+
     // Create the new config.json.
     let config_json = ConfigJson {
-        dl: base_url.to_string(),
+        dl: crate_path,
         api: base_url.to_string(),
     };
     let contents = serde_json::to_vec_pretty(&config_json)?;
