@@ -1,4 +1,6 @@
-use std::path::Path;
+use std::collections::HashSet;
+use std::net::{IpAddr, SocketAddr};
+use std::path::{Path, PathBuf};
 use std::{fs, io};
 
 use console::style;
@@ -8,6 +10,9 @@ use thiserror::Error;
 
 use crate::crates::is_new_crates_format;
 use crate::crates_index::rewrite_config_json;
+use crate::download::download_string;
+use crate::rustup::Channel;
+use crate::serve::TlsConfig;
 
 #[derive(Error, Debug)]
 pub enum MirrorError {
@@ -17,6 +22,10 @@ pub enum MirrorError {
     Parse(#[from] toml::de::Error),
     #[error("Config file error: {0}")]
     Config(String),
+    #[error("Command line error: {0}")]
+    CmdLine(String),
+    #[error("Download error: {0}")]
+    DownloadError(#[from] crate::download::DownloadError),
 }
 
 #[derive(Serialize, Deserialize, Debug)]
@@ -244,3 +253,77 @@ pub fn sync_crates(
 
     eprintln!("{}", style("Syncing Crates repositories complete!").bold());
 }
+
+pub fn serve(
+    path: PathBuf,
+    listen: Option<IpAddr>,
+    port: Option<u16>,
+    cert_path: Option<PathBuf>,
+    key_path: Option<PathBuf>,
+) -> Result<(), MirrorError> {
+    let listen = listen.unwrap_or_else(|| {
+        "::".parse()
+            .expect(":: IPv6 address should never fail to parse")
+    });
+    let port = port.unwrap_or_else(|| if cert_path.is_some() { 8443 } else { 8080 });
+    let socket_addr = SocketAddr::new(listen, port);
+
+    let rt = tokio::runtime::Runtime::new()?;
+
+    match (cert_path, key_path) {
+        (Some(cert_path), Some(key_path)) => rt.block_on(crate::serve::serve(
+            path,
+            socket_addr,
+            Some(TlsConfig {
+                cert_path,
+                key_path,
+            }),
+        )),
+        (None, None) => rt.block_on(crate::serve::serve(path, socket_addr, None)),
+        (Some(_), None) => {
+            return Err(MirrorError::CmdLine(
+                "cert_path set but key_path not set.".to_string(),
+            ))
+        }
+        (None, Some(_)) => {
+            return Err(MirrorError::CmdLine(
+                "key_path set but cert_path not set.".to_string(),
+            ))
+        }
+    };
+
+    Ok(())
+}
+
+/// Print out a list of all platforms.
+pub(crate) fn list_platforms(source: String, channel: String) -> Result<(), MirrorError> {
+    let channel_url = format!("{}/dist/channel-rust-{}.toml", source, channel);
+    let user_agent = HeaderValue::from_str(&format!("Panamax/{}", env!("CARGO_PKG_VERSION")))
+        .expect("Hardcoded user agent string should never fail.");
+    let channel_str = download_string(&channel_url, &user_agent)?;
+    let channel_data: Channel = toml::from_str(&channel_str)?;
+
+    let mut targets = HashSet::new();
+
+    for (_, pkg) in channel_data.pkg {
+        for (target, _) in pkg.target {
+            if target == "*" {
+                continue;
+            }
+            targets.insert(target);
+        }
+    }
+
+    let mut targets: Vec<String> = targets.into_iter().collect();
+    targets.sort();
+
+    println!(
+        "All currently available platforms for the {} channel:",
+        channel
+    );
+    for t in targets {
+        println!("  {}", t);
+    }
+
+    Ok(())
+}
